@@ -7,7 +7,8 @@
 #     # print('pyCHM as done this for you')
 #     dask.config.set(scheduler='processes')
 
-from CHM.vtu import *
+# from CHM.vtu import *
+from CHM.ugrid import *
 import CHM.conversion as conversion
-
-
+from CHM.utils import *
+from CHM.ugrid2tiff import *
